@@ -15,16 +15,16 @@ import os # delete
 
 # Additional Resources
 
-from resources.commands_list import cmdList
-from system_parser.tokens import tokens
-from system_parser.tokens_definition import *
+from .resources.commands_list import cmdList
+from .system_parser.tokens import tokens
+from .system_parser.tokens_definition import *
 
 # Commands
 
-import modules.options as options
-import modules.create as create
-import modules.goto as goto
-import modules.list as list_cmd
+from .modules import options as options
+from .modules import create as create
+from .modules import goto as goto
+from .modules import list as list_cmd
 
 #-------------------------------------------
 # ___________GLOBAL VARIABLES_______________
